pub trait RobustKernel {
// Required methods
fn weight(&self, residual: f64) -> f64;
fn rho(&self, residual: f64) -> f64;
}Expand description
Robust loss kernel used by registration and estimation algorithms.
pub trait RobustKernel {
// Required methods
fn weight(&self, residual: f64) -> f64;
fn rho(&self, residual: f64) -> f64;
}Robust loss kernel used by registration and estimation algorithms.